@@ -1,10 +1,9 @@
 package reader
 
 import (
-	"regexp"
-
 	"github.com/rivo/uniseg"
 	"github.com/walles/moor/v2/internal/linemetadata"
+	"github.com/walles/moor/v2/internal/search"
 	"github.com/walles/moor/v2/internal/textstyles"
 	"github.com/walles/moor/v2/twin"
 )
@@ -16,11 +15,11 @@ type NumberedLine struct {
 }
 
 func (nl *NumberedLine) Plain() string {
-	return nl.Line.Plain(&nl.Index)
+	return nl.Line.Plain(nl.Index)
 }
 
-func (nl *NumberedLine) HighlightedTokens(plainTextStyle twin.Style, searchHitStyle twin.Style, search *regexp.Regexp) textstyles.StyledRunesWithTrailer {
-	return nl.Line.HighlightedTokens(plainTextStyle, searchHitStyle, search, &nl.Index)
+func (nl *NumberedLine) HighlightedTokens(plainTextStyle twin.Style, searchHitStyle twin.Style, search search.Search) textstyles.StyledRunesWithTrailer {
+	return nl.Line.HighlightedTokens(plainTextStyle, searchHitStyle, search, nl.Index)
 }
 
 func (nl *NumberedLine) DisplayWidth() int {
