@@ -30,9 +30,12 @@ import (
 // negotiable.
 const MAX_HIGHLIGHT_SIZE int64 = 2_000_000
 
-// 140k lines took 20ms to search from a cold start. If we want to stay below
-// 100ms, we can do about 700k lines before pausing.
-const DEFAULT_PAUSE_AFTER_LINES = 700_000
+// To cap resource usage when not needed, start by reading this many lines into
+// memory. If the user scrolls near the end or starts searching, we'll read
+// more.
+//
+// Ref: https://github.com/walles/moor/issues/296
+const DEFAULT_PAUSE_AFTER_LINES = 50_000
 
 var DisablePlainCachingForBenchmarking = false
 
@@ -238,12 +241,21 @@ func (reader *ReaderImpl) maybePause() {
 // It is used both during the initial read of the stream until it ends, and
 // while tailing files for changes.
 func (reader *ReaderImpl) consumeLinesFromStream(stream io.Reader) {
+	// This value affects BenchmarkReadLargeFile() performance. Validate changes
+	// like this:
+	//
+	//   go test -benchmem -run='^$' -bench 'BenchmarkReadLargeFile' ./internal/reader
+
+	const linePoolSize = 1000
+
 	reader.preAllocLines()
 
 	inspectionReader := inspectionReader{base: stream}
-	bufioReader := bufio.NewReader(&inspectionReader)
+	bufioReader := bufio.NewReaderSize(&inspectionReader, 64*1024)
 	completeLine := make([]byte, 0)
 
+	linePool := make([]Line, linePoolSize)
+
 	t0 := time.Now()
 	for {
 		reader.maybePause()
@@ -292,16 +304,21 @@ func (reader *ReaderImpl) consumeLinesFromStream(stream io.Reader) {
 		}
 
 		newLineString := string(completeLine)
-		newLine := Line{raw: newLineString}
+		if len(linePool) == 0 {
+			linePool = make([]Line, linePoolSize)
+		}
+		newLine := &linePool[0]
+		linePool = linePool[1:]
+		newLine.raw = newLineString
 
 		reader.Lock()
 		if len(reader.lines) > 0 && !reader.endsWithNewline {
 			// The last line didn't end with a newline, append to it
 			newLineString = reader.lines[len(reader.lines)-1].raw + newLineString
-			newLine = Line{raw: newLineString}
-			reader.lines[len(reader.lines)-1] = &newLine
+			newLine = &Line{raw: newLineString}
+			reader.lines[len(reader.lines)-1] = newLine
 		} else {
-			reader.lines = append(reader.lines, &newLine)
+			reader.lines = append(reader.lines, newLine)
 		}
 		reader.endsWithNewline = true
 
